agentle.agents.agent\_config
============================

.. automodule:: agentle.agents.agent_config

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
      model_validator
   
   .. rubric:: Classes

   .. autosummary::
   
      AgentConfig
      BaseModel
      GenerationConfig
      GenerationConfigDict
   